==> owncloud-app-contacts-2%3A1.1.0.0-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/templates/main.php <==
<?php
// angular + components
script('contacts', 'vendor/angular/angular');
script('contacts', 'vendor/angular-route/angular-route');
script('contacts', 'vendor/angular-uuid4/angular-uuid4');
script('contacts', 'vendor/angular-cache/dist/angular-cache');
script('contacts', 'vendor/angular-sanitize/angular-sanitize');
script('contacts', 'vendor/ui-select/dist/select');

// DAV libraries
script('contacts', 'dav/dav');
script('contacts', 'vendor/vcard/src/vcard');

// compiled version of app javascript
script('contacts', 'public/script');

script('contacts', 'vendor/angular-bootstrap/ui-bootstrap.min');
script('contacts', 'vendor/angular-bootstrap/ui-bootstrap-tpls.min');
script('contacts', 'vendor/jquery-timepicker/jquery.ui.timepicker');

// all styles
style('contacts', 'public/style');
vendor_style('select2/select2');
?>

<div id="app" ng-app="contactsApp">
	<div id="app-navigation">

		<ul groupList></ul>

		<div id="app-settings">
			<div id="app-settings-header">
				<button class="settings-button"
						data-apps-slide-toggle="#app-settings-content">
					<?php p($l->t('Settings'));?>
				</button>
			</div>
			<div id="app-settings-content">
				<addressBookList></addressBookList>
				<input type="file" id="contact-import" class="hidden-visually" contactimport />
				<label for="contact-import" class="button" id="upload">
					<?php p($l->t('Import'));?>
					<span class="icon-upload"></span>
				</label>
			</div>
		</div>
	</div>

	<div id="app-content">
		<div class="app-content-list">
			<contactlist></contactlist>
		</div>
		<div class="app-content-detail" ng-view></div>
	</div>
</div>

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/templates/main.php <==
<?php
// angular + components
script('contacts', 'vendor/angular/angular');
script('contacts', 'vendor/angular-route/angular-route');
script('contacts', 'vendor/angular-uuid4/angular-uuid4');
script('contacts', 'vendor/angular-cache/dist/angular-cache');
script('contacts', 'vendor/angular-sanitize/angular-sanitize');
script('contacts', 'vendor/ui-select/dist/select');

// DAV libraries
script('contacts', 'dav/dav');
script('contacts', 'vendor/vcard/src/vcard');

// compiled version of app javascript
script('contacts', 'public/script');

script('contacts', 'vendor/angular-bootstrap/ui-bootstrap.min');
script('contacts', 'vendor/angular-bootstrap/ui-bootstrap-tpls.min');
script('contacts', 'vendor/jquery-timepicker/jquery.ui.timepicker');
script('contacts', 'vendor/clipboard/dist/clipboard.min');
script('contacts', 'vendor/ngclipboard/dist/ngclipboard.min');

// all styles
style('contacts', 'public/style');
vendor_style('select2/select2');
?>

<div id="app" ng-app="contactsApp">
	<div id="app-navigation">
		<newContactButton></newContactButton>
		<ul groupList></ul>

		<div id="app-settings">
			<div id="app-settings-header">
				<button class="settings-button"
						data-apps-slide-toggle="#app-settings-content">
					<?php p($l->t('Settings'));?>
				</button>
			</div>
			<div id="app-settings-content">
				<addressBookList></addressBookList>
				<contactImport></contactImport>
			</div>
		</div>
	</div>

	<div id="app-content">
		<div class="app-content-list">
			<contactlist></contactlist>
		</div>
		<div class="app-content-detail" ng-view></div>
	</div>
</div>
